@@ -378,6 +378,7 @@ enum filterTypes {
   _CREATOR = FLAG(10),
   MAXSIZE = FLAG(11),
   QUERY = FLAG(12),
+  NAME = FLAG(13),
 };
 
 Filter& Filter::local(bool accept)
@@ -465,24 +466,35 @@ Filter& Filter::query(std::string query)
   return *this;
 }
 
+Filter& Filter::name(std::string name)
+{
+  _name = name;
+  activeFilters |= NAME;
+  return *this;
+}
+
 #define ACTIVE(X) (activeFilters & (X))
+#define FILTER(TAG, TEST) if (ACTIVE(TAG) && !(TEST)) { return false; }
 bool Filter::accept(const Book& book) const
 {
   auto local = !book.getPath().empty();
-  if (ACTIVE(_LOCAL) && !local)
-    return false;
-  if (ACTIVE(_NOLOCAL) && local)
-    return false;
+  FILTER(_LOCAL, local)
+  FILTER(_NOLOCAL, !local)
+
   auto valid = book.isPathValid();
-  if (ACTIVE(_VALID) && !valid)
-    return false;
-  if (ACTIVE(_NOVALID) && valid)
-    return false;
+  FILTER(_VALID, valid)
+  FILTER(_NOVALID, !valid)
+
   auto remote = !book.getUrl().empty();
-  if (ACTIVE(_REMOTE) && !remote)
-    return false;
-  if (ACTIVE(_NOREMOTE) && remote)
-    return false;
+  FILTER(_REMOTE, remote)
+  FILTER(_NOREMOTE, !remote)
+
+  FILTER(MAXSIZE, book.getSize() <= _maxSize)
+  FILTER(LANG, book.getLanguage() == _lang)
+  FILTER(_PUBLISHER, book.getPublisher() == _publisher)
+  FILTER(_CREATOR, book.getCreator() == _creator)
+  FILTER(NAME, book.getName() == _name)
+
   if (ACTIVE(ACCEPTTAGS)) {
     if (!_acceptTags.empty()) {
       auto vBookTags = split(book.getTags(), ";");
@@ -505,18 +517,6 @@ bool Filter::accept(const Book& book) const
       }
     }
   }
-  if (ACTIVE(MAXSIZE) && book.getSize() > _maxSize)
-    return false;
-
-  if (ACTIVE(LANG) && book.getLanguage() != _lang)
-    return false;
-
-  if (ACTIVE(_PUBLISHER) && book.getPublisher() != _publisher)
-    return false;
-
-  if (ACTIVE(_CREATOR) && book.getCreator() != _creator)
-    return false;
-
   if ( ACTIVE(QUERY)
     && !(matchRegex(book.getTitle(), "\\Q" + _query + "\\E")
         || matchRegex(book.getDescription(), "\\Q" + _query + "\\E")))
