@@ -22,6 +22,8 @@
 
 #include <zim/search.h>
 
+#include "tools/otherTools.h"
+
 inline char hi(char v)
 {
   char hex[] = "0123456789abcdef";
@@ -352,43 +354,6 @@ string Reader::getLicense() const
   METADATA("License")
 }
 
-std::vector<std::string> convertTags(const std::string& tags_str)
-{
-  auto tags = split(tags_str, ";");
-  std::vector<std::string> tagsList;
-  bool picSeen(false), vidSeen(false), detSeen(false), indexSeen(false);
-  for (auto tag: tags) {
-    picSeen |= (tag == "nopic" || startsWith(tag, "_pictures:"));
-    vidSeen |= (tag == "novid" || startsWith(tag, "_videos:"));
-    detSeen |= (tag == "nodet" || startsWith(tag, "_details:"));
-    indexSeen |= startsWith(tag, "_ftindex");
-    if (tag == "nopic") {
-      tagsList.push_back("_pictures:no");
-    } else if (tag == "novid") {
-      tagsList.push_back("_videos:no");
-    } else if (tag == "nodet") {
-      tagsList.push_back("_details:no");
-    } else if (tag == "_ftindex") {
-      tagsList.push_back("_ftindex:yes");
-    } else {
-      tagsList.push_back(tag);
-    }
-  }
-  if (!indexSeen) {
-    tagsList.push_back("_ftindex:no");
-  }
-  if (!picSeen) {
-    tagsList.push_back("_pictures:yes");
-  }
-  if (!vidSeen) {
-    tagsList.push_back("_videos:yes");
-  }
-  if (!detSeen) {
-    tagsList.push_back("_details:yes");
-  }
-  return tagsList;
-}
-
 string Reader::getTags(bool original) const
 {
   string tags_str;
@@ -400,26 +365,6 @@ string Reader::getTags(bool original) const
   return join(tags, ";");
 }
 
-string getTagValueFromTagList(const std::vector<std::string>& tagList, const std::string& tagName)
-{
-  for (auto tag: tagList) {
-    if (tag[0] == '_') {
-      auto delimPos = tag.find(':');
-      if (delimPos == string::npos) {
-        // No delimiter... what to do ?
-        continue;
-      }
-      auto cTagName = tag.substr(1, delimPos-1);
-      auto cTagValue = tag.substr(delimPos+1);
-      if (cTagName == tagName) {
-        return cTagValue;
-      }
-    }
-  }
-  std::stringstream ss;
-  ss << tagName << " cannot be found";
-  throw std::out_of_range(ss.str());
-}
 
 string Reader::getTagStr(const std::string& tagName) const
 {
@@ -430,16 +375,7 @@ string Reader::getTagStr(const std::string& tagName) const
 
 bool Reader::getTagBool(const std::string& tagName) const
 {
-  auto tagValue = getTagStr(tagName);
-  if (tagValue == "yes") {
-    return true;
-  } else if (tagValue == "no") {
-    return false;
-  } else {
-    std::stringstream ss;
-    ss << "Tag value '" << tagValue << "' for " << tagName << " cannot be converted to bool.";
-    throw std::domain_error(ss.str());
-  }
+  return convertStrToBool(getTagStr(tagName));
 }
 
 string Reader::getRelation() const
