@@ -742,7 +742,6 @@ Response InternalServer::handle_catalog(const RequestContext& request)
   kiwix::OPDSDumper opdsDumper;
   opdsDumper.setRootLocation(m_root);
   opdsDumper.setSearchDescriptionUrl("catalog/searchdescription.xml");
-  opdsDumper.setId(kiwix::to_string(uuid));
   opdsDumper.setLibrary(mp_library);
   response.set_mimeType("application/atom+xml;profile=opds-catalog;kind=acquisition; charset=utf-8");
   std::vector<std::string> bookIdsToDump;
@@ -751,17 +750,22 @@ Response InternalServer::handle_catalog(const RequestContext& request)
     uuid = zim::Uuid::generate(host);
     bookIdsToDump = mp_library->filter(kiwix::Filter().valid(true).local(true).remote(true));
   } else if (url == "search") {
-    std::string query;
-    std::string language;
-    std::vector<std::string> tags;
-    std::vector<std::string> noTags;
+    auto filter = kiwix::Filter().valid(true).local(true).remote(true);
+    string query("<Empty query>");
     size_t count(10);
     size_t startIndex(0);
     try {
       query = request.get_argument("q");
+      filter.query(query);
     } catch (const std::out_of_range&) {}
     try {
-      language = request.get_argument("lang");
+      filter.maxSize(extractFromString<unsigned long>(request.get_argument("maxsize")));
+    } catch (...) {}
+    try {
+      filter.name(request.get_argument("name"));
+    } catch (const std::out_of_range&) {}
+    try {
+      filter.lang(request.get_argument("lang"));
     } catch (const std::out_of_range&) {}
     try {
       count = extractFromString<unsigned long>(request.get_argument("count"));
@@ -770,20 +774,14 @@ Response InternalServer::handle_catalog(const RequestContext& request)
       startIndex = extractFromString<unsigned long>(request.get_argument("start"));
     } catch (...) {}
     try {
-      tags = kiwix::split(request.get_argument("notag"), ";");
+      filter.acceptTags(kiwix::split(request.get_argument("tag"), ";"));
     } catch (...) {}
     try {
-      noTags = kiwix::split(request.get_argument("notag"), ";");
+      filter.rejectTags(kiwix::split(request.get_argument("notag"), ";"));
     } catch (...) {}
     opdsDumper.setTitle("Search result for " + query);
     uuid = zim::Uuid::generate();
-    bookIdsToDump = mp_library->filter(
-      kiwix::Filter().valid(true).local(true).remote(true)
-        .query(query)
-        .lang(language)
-        .acceptTags(tags)
-        .rejectTags(noTags)
-      );
+    bookIdsToDump = mp_library->filter(filter);
     auto totalResults = bookIdsToDump.size();
     bookIdsToDump.erase(bookIdsToDump.begin(), bookIdsToDump.begin()+startIndex);
     if (count>0 && bookIdsToDump.size() > count) {
@@ -792,6 +790,7 @@ Response InternalServer::handle_catalog(const RequestContext& request)
     opdsDumper.setOpenSearchInfo(totalResults, startIndex, bookIdsToDump.size());
   }
 
+  opdsDumper.setId(kiwix::to_string(uuid));
   response.set_content(opdsDumper.dumpOPDSFeed(bookIdsToDump));
   return response;
 }
